<?php
/*****************************************************************************
 * ID   : $Id: PageObject.php,v 1.2 2007/08/18 08:13:57 secondarykey Exp $
 * Name : ページオブジェクト
 * Specifications : 表示用ページオブジェクト
 * 「$page」でテンプレートからアクセス可能である
 ****************************************************************************/
class PageObject
{
	//基本的なページ用のオブジェクト
	var $myPageTable = null;
	//ページが持つ属性のスキーマ配列
	var $mySchemaArray = null;
	//ページが持つテンプレートテーブル	
	var $myTemplatePageTable = null;
	//ページが持つ変数の配列	
	var $myVariableArray = null;
	//ディレクトリ表示する場合のページの番号
	var $myPageNum = 1;
	//ディレクトリ表示する場合の子ページの番号
	var $myChildrenPageNum = 1;

	//子ページのリスト	
	var $myChildrenList	= null;
	//子ページのページャー
	var $myChildrenPager = null;

	var $myPageList = null;
	var $myPagePager = null;

	//ページのログ配列
	var $myLogArray = null;
	//子のログ配列
	var $myChildrenLogArray = null;

	/**
	 * コンストラクタ
	 */
	function PageObject() {
	}

	/**
	 * オブジェクト生成
	 */	
	function createPageObject($aPageTable,$aPageNum = 1,$aChildrenPageNum = 1) {
	
		$pageObject = new PageObject;	
		//ページオブジェクトを設定
		$pageObject->setPageTable($aPageTable);
		$pageObject->setPageNum($aPageNum);
		$pageObject->setChildrenPageNum($aChildrenPageNum);
		
		return $pageObject;
	}

	/**
	 * ページテーブルの設定
	 */	
	function setPageTable( $aPageTable ) {
		$this->myPageTable = $aPageTable;
	}

	/**
	 * ページ番号の設定
	 */	
	function setPageNum($aPageNum) {
		$this->myPageNum = $aPageNum;
	}
	
	/**
	 * 子ページ番号の設定
	 */	
	function setChildrenPageNum($aChildrenPageNum) {
		$this->myChildrenPageNum = $aChildrenPageNum;
	}
	
	
	/****************************************
	 * 以下は公開しているAPI
	 ****************************************/
	/**
	 * 名称の取得
	 */	
	function name() {
		return $this->myPageTable->getName();
	}
	
	/**
	 * 説明の取得
	 */
	function detail($aBRFlag = true) {
		$detail = $this->myPageTable->getDetail();
		if ( $aBRFlag ) {
			$detail = str_replace("\x0D\x0A", "<br>", $detail); 
		}
		return $detail;
	}

	/**
	 * ページイメージを取得
	 */	
	function img($aNum) {
		//ページのIDの取得
		$id = $this->myPageTable->getID();
		//タグを取得
		return image_tb::getPageImageTag($id,$aNum);
	}
	
	/**
	 * ページイメージを取得
	 */
	function imgsrc($aNum) {
		//ページのIDの取得
		$id = $this->myPageTable->getID();
		//タグを取得
		return image_tb::getPageImageSrc($id,$aNum);
	}
	
	/**
	 * ページイメージを取得
	 */
	function imgID() {
		//ページのIDの取得
		$id = $this->myPageTable->getID();
		//タグを取得
		return "IMG".$id;
	}

	/**
	 * ページのリンク先の取得
	 */	
	function src() {
		$id = $this->myPageTable->getID();
		return "./index.php?id=" . $id;
	}
	
	/**
	 * ページのリンク先の取得
	 */	
	function upper() {
		$id = $this->myPageTable->getParent_ID();
		$src = "./index.php";
		if ( $id != 0 ) {
			$src = $src . "?id=".$id;
		}
		return $src;
	}
	
	/**
	 * 作成日付を取得
	 */	
	function createdate() {
		return $this->myPageTable->getCreateDate();
	}
	
	/**
	 * 更新日付を取得
	 */	
	function editdate() {
		return $this->myPageTable->getEditDate();
	}

	/**
	 * 属性の取得
	 * $aVariableName = 変数名（属性の変数）
	 * $aSrcFlag = 画像をタグで取得するか、パスで取得するか
	 */	
	function get($aVariableName,$aSrcFlag=false) {

		//設定が存在しない場合
		$variArray = $this->getVariableArray();
		//ページのスキーマ情報の取得
		$schemaArray = $this->getSchemaTable();
		//データを取得する
		$value = $variArray[$aVariableName];
	
		//属性のタイプでデータを直接変更する
		foreach ( $schemaArray as $elm ) {
			//スキーマの変数名を取得
			$vari = $elm->getVariable();
			//取得する変数でない場合
			if ( $vari != $aVariableName ) {
				//処理を行わない
				continue;
			}
			//変数のタイプを取得
			$type = $elm->getVariableType();
			switch ( $type ) {
				case 0:
				case 2:
					$wk = TextObject::changePlaneText($value);
					$value=$wk;
				break;
				case 4:
					//IDを取得
					$id = $this->myPageTable->getID();
					//パス指定の場合
					if ( $aSrcFlag ) {
						//画像ファイル名を取得
						$wkvalue = image_tb::getAttributeImageSrc($id,$aVariableName);
					} else {
						//画像タグを取得
						$wkvalue = image_tb::getAttributeImageTag($id,$aVariableName);
					}
					//値として採用
					$value = $wkvalue;
				break;
			}
			//処理を終了する
			break;	
		}

		return $value;
	}

	/**
	 * ページの階層リスト
	 */	
	function navigationList() {
		
		$rootID = PAGE_ROOTID;
		$targetID = 0;
		
		$pageObject = $this->myPageTable;
		$navigationList = array();

		//同一のIDでない場合	
		while ( $targetID != $rootID ) {
			//ナビに追加	
			$navigationList[] = PageObject::createPageObject($pageObject);
			//ターゲットIDを今のページで設定
			$targetID = $pageObject->getID();
			//親のIDを設定	
			$parentID = $pageObject->getParent_ID();
			//ページのアクセスを生成	
			$page_tb = new page_tb();
			//ページ検索を行う
			$pageArray = $page_tb->selectByID($parentID);
			//処理中のオブジェクトで設定
			$pageObject = $pageArray[0];
		}	
		//リスト順を逆にする
		$rtnList = array_reverse($navigationList, True);
		//タグを取得
		return $rtnList;
	}

	/**
	 * 検索リスト
	 */
	function searchList($aPageArray) {

		$searchList = array();
		if ( $aPageArray == null ) return $searchList;
		//同一のIDでない場合	
		foreach ( $aPageArray as $pageTb ) {
			//ナビに追加	
			$searchList[] = PageObject::createPageObject($pageTb);
		}	
		//タグを取得
		return $searchList;
	}

	/**
	 * RSSのリストを返す
	 */
	function RSSTag() {
		$rtn = '<link rel="alternate" ' .
			'type="application/rss+xml" ' .
			'title="RSS 2.0" ' .
			'href="./rss.php?id=' . 
			$this->myPageTable->getParent_ID() . '">';
		return $rtn;
	}
	
	//下階層のRSSのURLを返す
	function childrenRSSTag() {
		$rtn = '<link rel="alternate" ' .
			'type="application/rss+xml" ' .
			'title="RSS 2.0" ' .
			'href="./rss.php?id=' . 
			$this->myPageTable->getID() . '">';
		return $rtn;
	}

	/**
	 * 子階層リストを取得
	 */	
	function childrenList() {
		$childList = $this->getChildrenList();
		return $childList;
	}

	/**
	 * 同階層リストを取得
	 */	
	function pageList() {
		//テンプレートページから子の表示条件を取得
		$pageList = $this->getPageList();
		return $pageList;
	}

	/**
	 * 更新リストの取得
	 */
	function updateList() {
		return $this->getLogArray($this->myPageTable->getParent_ID(),false);
	}
	
	/**
	 * 子更新リストの取得
	 */
	function updateChildrenList() {
		return $this->getLogArray($this->myPageTable->getID(),true);
	}
	
	/****************************************
	 * 以上は公開しているAPI これ以下は便利関数
	 ****************************************/
	 
	/**
	 * スキーマテーブル展開
	 */
	function getSchemaTable() {
		if ( $this->mySchemaArray == null ) {
			$schema_tb = new schema_tb;
			//スキーマを検索
			$schemaArray = $schema_tb->selectTemplatePageID($this->myPageTable->getTemplate_Page_ID());
			//スキーマを代入
			$this->mySchemaArray = $schemaArray;
		}
		return $this->mySchemaArray;
	}

	/**
	 * テンプレートテーブル展開
	 */	
	function getTemplatePageTable() {
		if ( $this->myTemplatePageTable == null ) {
			$template_page_tb = new template_page_tb;
			//スキーマを検索
			$tempArray = $template_page_tb->selectByID($this->myPageTable->getTemplate_Page_ID());
			//スキーマを代入
			$this->myTemplatePageTable = $tempArray[0];
		}
		return $this->myTemplatePageTable;
	}

	/**
	 * 変数定義展開
	 */	
	function getVariableArray() {
		
		//設定が存在しない場合
		if ( $this->myVariableArray == null ) {
			$table = new page_attribute_tb;
			//フィールド名をキーにした配列を返す
			$this->myVariableArray = $table->getFieldArray($this->myPageTable->getTemplate_Page_ID(),$this->myPageTable->getID());
		}
		return $this->myVariableArray;
	}

	/**
	 * 子ページの作成
	 */
	function getChildrenList() {

		if ( $this->myChildrenList == null ) {
			//テンプレートページから子の表示条件を取得
			$tmpTable = $this->getTemplatePageTable();
			$chListNum = $tmpTable->getChildrenListNum();
			$chListPageNum = $tmpTable->getChildrenListPageNum();
	
			$id = $this->myPageTable->getID();
			
			$page_tb = new page_tb();
			$page_tb->setLimit($chListNum);
	
			//表示できるページを作成	
			$pageArray = $page_tb->getPageList($id,$this->myChildrenPageNum);

			$pageList = array();
			if ( $pageArray == null ) {
				$this->myChildrenList = $pageList;
				return $pageList;
			}
	
			foreach ($pageArray as $page) {
				$pageList[] = PageObject::createPageObject($page);
			}
			$this->myChildrenList = $pageList;

			//自分のIDを取得
			$pageID = "";
			if ( $this->myPageNum != 1 ) {
				$pageID = "&page=".$this->myPageNum;	
			}
			//ページャーを生成(ページ名称,現在のページ,最後のページ,ページリスト表示数)
			$pager = new Pager("index.php?id=".$id.$pageID);
			$pager->setPageID("cpage");
			//解析を行う
			$pager->analytics($this->myChildrenPageNum,$page_tb->getMaxPageNum(),$chListPageNum);
			$myChildrenPager = $pager;
		}
		return $this->myChildrenList;
	}

	/**
	 * ページの作成
	 */
	function getPageList() {

		if ( $this->myPageList == null ) {
			//テンプレートページから子の表示条件を取得
			$tmpTable = $this->getTemplatePageTable();
			$pageListNum = $tmpTable->getPageListNum();
			$pageListPageNum = $tmpTable->getPageListPageNum();
	
			$id = $this->myPageTable->getID();
			$pid = $this->myPageTable->getParent_ID();
			
			$page_tb = new page_tb();
			$page_tb->setLimit($pageListNum);
	
			//表示できるページを作成	
			$pageArray = $page_tb->getPageList($pid,$this->myPageNum);

			$pageList = array();
			if ( $pageArray == null ) {
				$this->myPageList = $pageList;
				return $pageList;
			}
	
			foreach ($pageArray as $page) {
				$pageList[] = PageObject::createPageObject($page);
			}
			$this->myPageList = $pageList;

			//自分のIDを取得
			$pageID = "";
			if ( $this->myPageNum != 1 ) {
				$pageID = "&cpage=".$this->myPageNum;	
			}
			//ページャーを生成(ページ名称,現在のページ,最後のページ,ページリスト表示数)
			$pager = new Pager("index.php?id=".$id.$pageID);
			//解析を行う
			$pager->analytics($this->myPageNum,$page_tb->getMaxPageNum(),$pageListPageNum);
			$myPagePager = $pager;
		}
		return $this->myPageList;
	}
	
	/**
	 * ログオブジェクト取得
	 */
	function getLogArray($aID,$aFlag) {

		$rtnlogs = null;
		if ( $aFlag ) {
			$rtnlogs = $this->myLogChildrenArray;
		} else {
			$rtnlogs = $this->myLogArray;
		}

		if ( $rtnlogs == null ) {
			$logtb = new log_tb;
			$logs = array();
			$logTables = $logtb->selectByRSS($aID);
			if ( $logTables != null ) {
				foreach ( $logTables as $log )	{
					$logs[] = new LogObject($log);
				}
			}
			$rtnlogs = $logs;
		}
		
		if ( $aFlag ) {
			$this->myLogChildrenArray = $rtnlogs;
			$rtnlogs = $this->myLogChildrenArray;
		} else {
			$this->myLogArray = $rtnlogs;
			$rtnlogs = $this->myLogArray;
		}
		return $rtnlogs;
	}
}
?>
